"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShadowView = exports.LinearShadowView = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _utils = require("../utils.js");
var _constants = require("../constants.js");
var _reactNativeSkia = require("@shopify/react-native-skia");
var _ShadowLinearGradientFill = _interopRequireDefault(require("./ShadowLinearGradientFill.js"));
var _CornerRadii = require("./CornerRadii.js");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * A unified interface for both "solid" (InnerShadow) and "linear" (LinearShadow).
 * We automatically detect "linear mode" by checking if the user provides
 * gradient props (colors, from, to, etc.).
 */const UnifiedShadowView = /*#__PURE__*/(0, _react.memo)(function UnifiedShadowView({
  width: propWidth,
  height: propHeight,
  inset,
  isReflectedLightEnabled,
  style,
  backgroundColor,
  shadowOffset,
  shadowColor,
  shadowBlur,
  reflectedLightOffset,
  reflectedLightColor,
  reflectedLightBlur,
  onLayout: propsOnLayout,
  children,
  ...props
}) {
  // Extract base fields
  const flatStyle = (0, _react.useMemo)(() => _reactNative.StyleSheet.flatten(style) || {}, [style]);
  const bgColor = (0, _utils.getBackgroundColor)({
    backgroundColor,
    styleBackground: flatStyle.backgroundColor
  });
  const shadowProps = (0, _utils.getShadowProperty)({
    shadowOffset,
    shadowColor,
    shadowBlur,
    reflectedLightOffset,
    reflectedLightColor,
    reflectedLightBlur
  });
  const isLinear = (0, _utils.isLinearProps)(props);

  // If isReflectedLightEnabled is undefined, default to `props.inset` (typical).
  const _isReflectedLightEnabled = isReflectedLightEnabled ?? inset;
  const initialW = propWidth ?? (0, _utils.numerify)(flatStyle.width, 0);
  const initialH = propHeight ?? (0, _utils.numerify)(flatStyle.height, 0);
  const [layout, setLayout] = (0, _react.useState)({
    width: initialW,
    height: initialH
  });
  const onLayout = _react.default.useCallback(e => {
    propsOnLayout?.(e);
    if (initialW && initialH) return;
    const {
      width,
      height
    } = e.nativeEvent.layout;
    setLayout(prev => prev.width === width && prev.height === height ? prev : {
      width,
      height
    });
  }, [initialW, initialH, propsOnLayout]);
  // Create offset style for outer shadow if needed
  const outerShadowOffset = _react.default.useMemo(() => (0, _utils.getOuterShadowOffset)({
    ...shadowProps,
    inset
  }), [shadowProps, inset]);

  // 현재 적용할 실제 크기 (명시 prop 우선, 아니면 측정값)
  const finalWidth = layout.width;
  const finalHeight = layout.height;
  const canRenderCanvas = finalWidth && finalHeight;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
    ...props,
    style: [outerShadowOffset,
    // Possibly sets outer drop-shadow if needed
    _constants.COMMON_STYLES.canvasWrapper, style],
    onLayout: onLayout,
    children: [canRenderCanvas ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Canvas, {
      style: [_constants.COMMON_STYLES.canvas, {
        width: finalWidth,
        height: finalHeight
      }],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_CornerRadii.CornerRadii, {
        width: finalWidth,
        height: finalHeight,
        style: style,
        backgroundColor: bgColor,
        children: [isLinear && /*#__PURE__*/(0, _jsxRuntime.jsx)(_ShadowLinearGradientFill.default, {
          ...props,
          // from, to, colors, etc.
          width: finalWidth,
          height: finalHeight
        }), inset && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: shadowProps.shadowOffset.width,
          dy: shadowProps.shadowOffset.height,
          blur: shadowProps.shadowBlur,
          color: shadowProps.shadowColor,
          inner: true
        }), _isReflectedLightEnabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: shadowProps.reflectedLightOffset.width,
          dy: shadowProps.reflectedLightOffset.height,
          blur: shadowProps.reflectedLightBlur,
          color: shadowProps.reflectedLightColor,
          inner: true
        })]
      })
    }) : null, children]
  });
});

/**
 * ShadowView: for a basic “solid” background shadow(no gradient props).
 *
 * @remarks
 * See {@link InnerShadowProps} for a linear gradient background shadow.
 *
 * @example
 * ```ts
 * <ShadowView style={styles.shadowView} inset>
 *   <Text>ShadowView</Text>
 * </ShadowView>
 * ```
 */
const ShadowView = exports.ShadowView = UnifiedShadowView;

/**
 * LinearShadowView: for a linear gradient background shadow
 * (requires e.g. colors, from, to).
 *
 * @remarks
 * See {@link LinearInnerShadowProps} for a solid background shadow.
 *
 * @example
 * ```ts
 *  <LinearShadowView
 *    style={styles.shadowView}
 *    colors={['#f1c40f', '#e74c3c']}
 *    from="top"
 *  >
 *    <Text>LinearShadowView</Text>
 *  </LinearShadowView>
 * ```
 */
const LinearShadowView = exports.LinearShadowView = UnifiedShadowView;
//# sourceMappingURL=ShadowView.js.map